# Compartment based scaledown model

**Compartment based scaledown model (cbsm)** is a Python package for creating compartments of a bioreactor.

## Usage

## Install

Install the latest version of **cbsm**:

`pip install cbsm`

## Bugs

Please report any bugs using the [issues](https://gitlab.gbar.dtu.dk/inno4vac/compartment-based-scaledown-model/-/issues) or contribute and fix the bug by following the steps in the [Contribution Guide](https://gitlab.gbar.dtu.dk/inno4vac/compartment-based-scaledown-model/-/blob/main/CONTRIBUTING.md). We welcome all contributions!

## License

Released under the **MIT license** (see LICENSE.txt)
